pivLib
======

.. automodule:: myimagelib.pivLib







   .. rubric:: Functions

   .. autosummary::
     :toctree: pivLib

      PIV
      PIV1
      PIV_masked
      read_piv
      tangent_unit
      apply_mask




   .. rubric:: Classes

   .. autosummary::
     :toctree: pivLib

      piv_data
      compact_PIV
